<?php declare(strict_types=1);

namespace BitBadger\PDODocument;

/**
 * Functions to delete documents
 */
class Delete
{
    /**
     * Delete a document by its ID
     *
     * @param string $tableName The table from which the document should be deleted
     * @param mixed $docId The ID of the document to be deleted
     * @throws DocumentException If any is encountered
     */
    public static function byId(string $tableName, mixed $docId): void
    {
        Custom::nonQuery(Query\Delete::byId($tableName), Parameters::id($docId));
    }

    /**
     * Delete documents by matching a comparison on JSON fields
     *
     * @param string $tableName The table from which documents should be deleted
     * @param array|Field[] $fields The field comparison to match
     * @param string $conjunction How to handle multiple conditions (optional; defaults to `AND`)
     * @throws DocumentException If any is encountered
     */
    public static function byFields(string $tableName, array $fields, string $conjunction = 'AND'): void
    {
        $namedFields = Parameters::nameFields($fields);
        Custom::nonQuery(Query\Delete::byFields($tableName, $namedFields, $conjunction),
            Parameters::addFields($namedFields, []));
    }
}
